<?php

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Util\SupUtilities;

class MinimoFornecedorPorRegiaoService {
    
    
    public function __construct(SupUtilities $supUtilities){
        $this->supUtilities      = $supUtilities;
    }
    
      /********************
     *      SELECTS    *
     * ******************/
    
    public function selectQtd($row){    
        
        $query  = "SELECT QTMINFORNREG, NRORG FROM MINFORNREG MIN WHERE MIN.CDFORNECED = :P_CDFORNECED AND QTMINFORNREG IS NOT NULL";
        $params = [
            'P_CDFORNECED'     => $row['CDFORNECED']
         
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function getRegiao($row){    
        
        $query  = "SELECT MIN.CDREGIAO, REG.NMREGIAO, MIN.QTMINFORNREG, MIN.VRMINFORNREG, FORN.SGUNIDADE, MIN.CDFORNECED, MIN.NRORG FROM FORNECEDOR FORN, REGIAO REG, MINFORNREG MIN WHERE(FORN.CDFORNECED = MIN.CDFORNECED) AND (MIN.CDREGIAO = REG.CDREGIAO) AND (FORN.CDFORNECED = :P_CDFORNECED) ORDER BY MIN.CDREGIAO";
        $params = [
            'P_CDFORNECED'     => $row['CDFORNECED']
         
        ];
        return $this->supUtilities->crud($query, $params);
    }
    
    public function getDadosFornecedor($row){    
        
        $query  = "SELECT IDTPIJURFORN, CDFORNECED, NRINSJURFORN, NMFANTFORN, NMRAZSOCFORN, VRMINAUTFOR, QTMINAUTFOT, SGUNIDADE, NRORG FROM FORNECEDOR WHERE ( FORNECEDOR.IDSITUCADA =:P_IDSITUCADA ) AND (FORNECEDOR.CDFORNECED = :P_CDFORNECED) AND ( NOT EXISTS ( SELECT QUALIFICACAO.CDQUALIF FROM QUALIFICACAO, PARASUPRI WHERE ( FORNECEDOR.CDQUALIF = QUALIFICACAO.CDQUALIF ) AND ( PARASUPRI.CDFILIAL =:P_CDFILIAL ) AND ( FORNECEDOR.IDFORNAUTO = 'N' ) AND ( ( QUALIFICACAO.IDPERCOTCMP = '2' ) OR ( ( PARASUPRI.IDULTIDTVALQ = 'D' AND TRUNC(SYSDATE) > FORNECEDOR.DTVALQUALIF ) OR ( PARASUPRI.IDULTIDTVALQ = 'M' AND TRUNC(SYSDATE) > LAST_DAY(FORNECEDOR.DTVALQUALIF) ) ) ) ) OR :P_TIDSITUCADA = 'T' )";
        $params = [
            'P_IDSITUCADA'      => $row['IDSITUCADA'],
            'P_CDFORNECED'      => $row['CDFORNECED'],
            'P_CDFILIAL'        => $row['CDFILIAL'],
            'P_TIDSITUCADA'     => null
         
        ];
        return $this->supUtilities->crud($query, $params);
    }
    /********************
     *      INSERTS     *
     * ******************/
    
    public function insertRegiao($row){    
        try {
            $query = "INSERT INTO MINFORNREG(CDREGIAO, CDFORNECED, QTMINFORNREG, VRMINFORNREG, NRORG) VALUES (:CDREGIAO, :CDFORNECED, :QTMINFORNREG, :VRMINFORNREG, :NRORG)";
            $params = [
                'CDREGIAO'     => $row['CDREGIAO'],
                'CDFORNECED'   => $row['CDFORNECED'],
                'QTMINFORNREG' => $row['QTMINFORNREG'],
                'VRMINFORNREG' => $row['VRMINFORNREG'],
                'NRORG'        => $row['NRORG']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir região!');
        }
    }

    /********************
     *      UPDATES     *
     * ******************/
     
     
    public function updateFornecedor($row) {
        
      
        try {
            $query = "UPDATE FORNECEDOR SET VRMINAUTFOR = :VRMINAUTFOR, QTMINAUTFOT = :QTMINAUTFOT, SGUNIDADE = :SGUNIDADE WHERE CDFORNECED = :OLD_CDFORNECED";
            $params = [
                'VRMINAUTFOR'    => $row['VRMINAUTFOR'],
                'QTMINAUTFOT'    => $row['QTMINAUTFOT'],
                'SGUNIDADE'      => $row['SGUNIDADE'],
                'OLD_CDFORNECED' => $row['CDFORNECED']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao atualizar fornecedor!');
        }
    }
     public function updateRegiao($row) {
        try {
            $query = "UPDATE MINFORNREG SET CDREGIAO = :CDREGIAO, CDFORNECED = :CDFORNECED, QTMINFORNREG = :QTMINFORNREG, VRMINFORNREG = :VRMINFORNREG WHERE CDREGIAO = :OLD_CDREGIAO AND CDFORNECED = :OLD_CDFORNECED";
            $params = [
                'CDREGIAO'      => $row['CDREGIAO'],
                'CDFORNECED'    => $row['CDFORNECED'],
                'QTMINFORNREG'  => $row['QTMINFORNREG'],
                'VRMINFORNREG'  => $row['VRMINFORNREG'],
                'OLD_CDREGIAO'  => $row['CDREGIAO'],
                'OLD_CDFORNECED'=> $row['CDFORNECED']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao atualizar região!');
        }
    }
    
    
    /********************
     *      DELETES     *
     * ******************/
     
    
    public function deleteRegiao($row) {
        try {
          $query = "DELETE FROM MINFORNREG WHERE CDREGIAO = :OLD_CDREGIAO AND CDFORNECED = :OLD_CDFORNECED";
            $params = [
                'OLD_CDREGIAO'   => $row['CDREGIAO'],
                'OLD_CDFORNECED' => $row['CDFORNECED']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao deletar região!');
        }
    }
}